user/dev discussion of public-inbox itself
 help / color / mirror / code / Atom feed
* [PATCH] nntpdeflate: reduce overhead of idle clients
@ 2019-07-14  2:56 Eric Wong
  0 siblings, 0 replies; only message in thread
From: Eric Wong @ 2019-07-14  2:56 UTC (permalink / raw)
  To: meta

We don't need to keep an empty buffer around in the common case
when a client is sending us completely inflatable requests and
we're able to read them in one go.

This only seems to save about 2M with 10K NNTPS clients using
COMPRESS, so it's not a huge win, but better than nothing.
---
 lib/PublicInbox/NNTPdeflate.pm | 13 ++++++++-----
 1 file changed, 8 insertions(+), 5 deletions(-)

diff --git a/lib/PublicInbox/NNTPdeflate.pm b/lib/PublicInbox/NNTPdeflate.pm
index f2de0f38..c143488f 100644
--- a/lib/PublicInbox/NNTPdeflate.pm
+++ b/lib/PublicInbox/NNTPdeflate.pm
@@ -56,7 +56,7 @@ sub enable {
 	unlock_hash(%$self);
 	$self->res('206 Compression active');
 	bless $self, $class;
-	$self->{zin} = [ $in, '' ];
+	$self->{zin} = $in;
 }
 
 # overrides PublicInbox::NNTP::compressed
@@ -67,13 +67,16 @@ sub do_read ($$$$) {
 	my ($self, $rbuf, $len, $off) = @_;
 
 	my $zin = $self->{zin} or return; # closed
-	my $deflated = \($zin->[1]);
-	my $r = PublicInbox::DS::do_read($self, $deflated, $len) or return;
+	my $doff;
+	my $dbuf = delete($self->{dbuf}) // '';
+	$doff = length($dbuf);
+	my $r = PublicInbox::DS::do_read($self, \$dbuf, $len, $doff) or return;
 
 	# assert(length($$rbuf) == $off) as far as NNTP.pm is concerned
-	# -ConsumeInput is true, so $deflated is automatically emptied
-	my $err = $zin->[0]->inflate($deflated, $rbuf);
+	# -ConsumeInput is true, so $dbuf is automatically emptied
+	my $err = $zin->inflate($dbuf, $rbuf);
 	if ($err == Z_OK) {
+		$self->{dbuf} = $dbuf if $dbuf ne '';
 		$r = length($$rbuf) and return $r;
 		# nothing ready, yet, get more, later
 		$self->requeue;
-- 
EW


^ permalink raw reply related	[flat|nested] only message in thread

only message in thread, other threads:[~2019-07-14  2:56 UTC | newest]

Thread overview: (only message) (download: mbox.gz / follow: Atom feed)
-- links below jump to the message on this page --
2019-07-14  2:56 [PATCH] nntpdeflate: reduce overhead of idle clients Eric Wong

Code repositories for project(s) associated with this public inbox

	https://80x24.org/public-inbox.git

This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox;
as well as URLs for read-only IMAP folder(s) and NNTP newsgroup(s).